==> release.12.0.73.1.tgz: prontus/cpan/js-local/PushNotif.class.js <==
(function (window) {
    var _self = null;
    var PushNotif = {
        debug: 0,
        validEvents: ['click', 'hover'],
        init: function () {
            _self = this;
            _self.ui.showLoading();
            _self.methods.bindEvents();
            _self.methods.getNotifList();
            PushNotif.validatorForm = new Validador('formModal', 'one', 'FDF8C1');
            PushNotif.validatorForm.addconstraint('push_title', 'obligatorio', '', 'Debes indicar Título');
            PushNotif.validatorForm.addconstraint('push_msg', 'obligatorio', '', 'Debes indicar Mensaje');
            PushNotif.validatorForm.addconstraint('push_url', 'obligatorio', '', 'Debes indicar URL');
            PushNotif.validatorForm.addconstraint('push_url', 'url', '', 'Debes ingresar una url válida');
            PushNotif.validatorForm.addconstraint('push_url_image', 'url', '', 'Debes ingresar una url de imagen válida');
        },
        actions: {
            refreshNotifList: function (e) {
                _self.ui.showLoading();
                _self.methods.getNotifList();
            },
            newNotif: function (e) {
                $('#modalNewNotif').modal('show');
            },
            enviarPushNotif: function (ui) {
                ui.e.preventDefault();
                ui.e.stopPropagation();

                if (!PushNotif.validatorForm.validar()) {
                    return;
                }

                showModalConfirm({
                    msg: "Se enviará una notificación push a todos los suscriptores. <br>¿Deseas continuar?",
                    okTitle: 'Enviar notificación',
                    btnClassOk: 'hovwhite radius15 noborder txtnextwhite pad-top-bot7 pad-lef-rig20 int-nextred nextred',
                    cbBtnOK: function () {
                        $.ajax({
                            type: "POST",
                            dataType: 'json',
                            url: '/' + Admin.dir_cgi_cpn + '/prontus_snp_send_push.cgi',
                            data: {
                                _prontus_id: Admin.prontus_id,
                                _title: $('#push_title').val(),
                                _message: $('#push_msg').val(),
                                _url: $('#push_url').val(),
                                _image: $('#push_url_image').val(),
                                web: document.getElementById('snp_web').checked,
                                android: document.getElementById('snp_android').checked,
                                ios: document.getElementById('snp_ios').checked
                            },
                            success: function (resp, textStatus, jqXHR) {
                                if (resp.status == 1) {
                                    showModalAlert({
                                        title: 'Notificación push',
                                        type: 'green',
                                        msg: 'Notificación enviada con éxito.',
                                        cbBtnOK: function () {
                                            $('#push_title').val('');
                                            $('#push_msg').val('');
                                            $('#push_url').val('');
                                            $('#push_url_image').val('');
                                            $('#modalNewNotif').modal('hide');
                                        }
                                    });
                                } else {
                                    showModalAlert({
                                        title: 'Notificación push',
                                        type: 'red',
                                        msg: 'Ocurrió un error al enviar: ' + resp.msg
                                    });
                                }
                            },
                            error: function(XMLHttpRequest, textStatus, errorThrown) {
                                showModalAlert({
                                    title: 'Notificación push',
                                    type: 'red',
                                    msg: 'Error en el envío: ' + textStatus
                                });
                            }
                        });
                    },
                    cbBtnCancel: function () {
                        return false;
                    }
                });
            }
        },
        methods: {
            bindEvents: function (force, parentSelector) {
                var selector;

                if (typeof force == 'undefined') force = 0;

                if (!force) {
                    selector = '[data-namespace="pushnotif"][data-event]:not([data-bind])';
                } else {
                    selector = '[data-namespace="pushnotif"][data-event]';
                }

                if (typeof parentSelector != 'undefined') {
                    selector = parentSelector + ' ' + selector;
                }

                $(selector).each(function () {
                    var method = $(this).attr("data-method");
                    var event = $(this).attr("data-event");

                    // Validar si es un evento válido.
                    if ($.inArray(event, _self.validEvents) >= 0) {
                        if (typeof method != 'undefined') {
                            $(this).attr("data-bind", "true");
                            $(this).off(event).on(event, function (e) {
                                e.preventDefault();
                                _self.helper.execFunction(method, PushNotif, {e: e, helper: $(this)});
                            });
                        }
                    }
                });
            },
            getNotifList: function () {
                $.ajax({
                    url: "/{0}/prontus_snp_get_notif.cgi".format(Admin.dir_cgi_cpn),
                    data: {
                        _prontus_id: Admin.prontus_id
                    },
                    dataType: 'json',
                    type: 'POST',
                    success: function (response) {
                        if (response.status == 1) {
                            _self.methods.parseNotifList(response.api_data);
                            _self.ui.hideLoading();
                        } else {
                            _self.ui.hideLoading();

                            showModalAlert({
                                title: "Ha ocurrido un error",
                                msg: response.msg,
                                type: "red",
                                icon: "glyphicon glyphicon-exclamation-sign",
                                cbBtnOK: function () {
                                }
                            });
                        }

                    },
                    error: function (XMLHttpRequest, textStatus, errorThrown) {
                        _self.ui.hideLoading();
                        showModalAlert({
                            title: "Ha ocurrido un error",
                            msg: "No se pudo cargar el listado de notificaciones: {0}".format(errorThrown),
                            type: "red",
                            icon: "glyphicon glyphicon-exclamation-sign",
                            cbBtnOK: function () {
                            }
                        });
                    }
                })
            },
            parseNotifList: function (data) {
                var tpl_list = $('#tpl_list').html();
                var list = '';

                for (var x = 0; x < data.length; x++) {
                    var aux = tpl_list;

                    for (var prop in data[x]) {
                        aux = aux.replace(new RegExp( '{{'+prop+'}}', "g"), data[x][prop]);
                    }

                    list += aux;
                }

                $('#notif-list').html(list);
            }
        },
        ui: {
            showLoading: function () {
                $('#modal-loading-mensaje').html('Por favor espera mientras Prontus carga la información');
                $('#modal-loading').modal({backdrop: 'static', keyboard: false});
            },
            hideLoading: function () {
              $('#modal-loading').modal('hide');
            }
        },
        helper: {
            execFunction: function (functionName, context) {
                var args = Array.prototype.slice.call(arguments, 2);
                var namespaces = functionName.split(".");
                var func = namespaces.pop();

                for(var i = 0; i < namespaces.length; i++) {
                    context = context[namespaces[i]];
                }

                if (typeof context[func] == 'undefined') {
                    showModalAlert({
                        title: 'Error',
                        type: 'red',
                        msg: 'El método ' + functionName + ' no existe.'
                    });
                    return;
                }

                return context[func].apply(context, args);
            }
        }
    };

    $(document).ready(function () {
        PushNotif.init();
    });
})(window);

==> release.12.3.1.2.tgz: prontus/cpan/js-local/PushNotif.class.js <==
(function (window) {
    var _self = null;
    var PushNotif = {
        debug: 0,
        validEvents: ['click', 'hover'],
        init: function () {
            _self = this;
            _self.ui.showLoading();
            _self.methods.bindEvents();
            _self.methods.getNotifList();
            PushNotif.validatorForm = new Validador('formModal', 'one', 'FDF8C1');
            PushNotif.validatorForm.addconstraint('push_title', 'obligatorio', '', ProntusL10n.get('prontus_title_required'));
            PushNotif.validatorForm.addconstraint('push_msg', 'obligatorio', '', ProntusL10n.get('prontus_msg_required'));
            PushNotif.validatorForm.addconstraint('push_url', 'obligatorio', '', ProntusL10n.get('prontus_url_required'));
            PushNotif.validatorForm.addconstraint('push_url', 'url', '', ProntusL10n.get('prontus_valid_url_required'));
            PushNotif.validatorForm.addconstraint('push_url_image', 'url', '', ProntusL10n.get('prontus_img_url_required'));
        },
        actions: {
            refreshNotifList: function (e) {
                _self.ui.showLoading();
                _self.methods.getNotifList();
            },
            newNotif: function (e) {
                $('#modalNewNotif').modal('show');
            },
            enviarPushNotif: function (ui) {
                ui.e.preventDefault();
                ui.e.stopPropagation();

                if (!PushNotif.validatorForm.validar()) {
                    return;
                }

                showModalConfirm({
                    msg: ProntusL10n.get('prontus_send_notification_msg'),
                    okTitle: ProntusL10n.get('prontus_send_notification_label'),
                    btnClassOk: 'hovwhite radius15 noborder txtnextwhite pad-top-bot7 pad-lef-rig20 int-nextred nextred',
                    cbBtnOK: function () {
                        $.ajax({
                            type: "POST",
                            dataType: 'json',
                            url: '/' + Admin.dir_cgi_cpn + '/prontus_snp_send_push.cgi',
                            data: {
                                _prontus_id: Admin.prontus_id,
                                _title: $('#push_title').val(),
                                _message: $('#push_msg').val(),
                                _url: $('#push_url').val(),
                                _image: $('#push_url_image').val(),
                                web: document.getElementById('snp_web').checked,
                                android: document.getElementById('snp_android').checked,
                                ios: document.getElementById('snp_ios').checked
                            },
                            success: function (resp, textStatus, jqXHR) {
                                if (resp.status == 1) {
                                    showModalAlert({
                                        title: ProntusL10n.get('prontus_notification_label'),
                                        type: 'green',
                                        msg: ProntusL10n.get('prontus_notification_success'),
                                        cbBtnOK: function () {
                                            $('#push_title').val('');
                                            $('#push_msg').val('');
                                            $('#push_url').val('');
                                            $('#push_url_image').val('');
                                            $('#modalNewNotif').modal('hide');
                                        }
                                    });
                                } else {
                                    showModalAlert({
                                        title: ProntusL10n.get('prontus_notification_label'),
                                        type: 'red',
                                        msg: ProntusL10n.get('prontus_notification_error', resp.msg)
                                    });
                                }
                            },
                            error: function(XMLHttpRequest, textStatus, errorThrown) {
                                showModalAlert({
                                    title: ProntusL10n.get('prontus_notification_label'),
                                    type: 'red',
                                    msg: ProntusL10n.get('prontus_notification_error', textStatus)
                                });
                            }
                        });
                    },
                    cbBtnCancel: function () {
                        return false;
                    }
                });
            }
        },
        methods: {
            bindEvents: function (force, parentSelector) {
                var selector;

                if (typeof force == 'undefined') force = 0;

                if (!force) {
                    selector = '[data-namespace="pushnotif"][data-event]:not([data-bind])';
                } else {
                    selector = '[data-namespace="pushnotif"][data-event]';
                }

                if (typeof parentSelector != 'undefined') {
                    selector = parentSelector + ' ' + selector;
                }

                $(selector).each(function () {
                    var method = $(this).attr("data-method");
                    var event = $(this).attr("data-event");

                    // Validar si es un evento válido.
                    if ($.inArray(event, _self.validEvents) >= 0) {
                        if (typeof method != 'undefined') {
                            $(this).attr("data-bind", "true");
                            $(this).off(event).on(event, function (e) {
                                e.preventDefault();
                                _self.helper.execFunction(method, PushNotif, {e: e, helper: $(this)});
                            });
                        }
                    }
                });
            },
            getNotifList: function () {
                $.ajax({
                    url: "/{0}/prontus_snp_get_notif.cgi".format(Admin.dir_cgi_cpn),
                    data: {
                        _prontus_id: Admin.prontus_id
                    },
                    dataType: 'json',
                    type: 'POST',
                    success: function (response) {
                        if (response.status == 1) {
                            _self.methods.parseNotifList(response.api_data);
                            _self.ui.hideLoading();
                        } else {
                            _self.ui.hideLoading();

                            showModalAlert({
                                title: ProntusL10n.get('admin_error'),
                                msg: response.msg,
                                type: "red",
                                icon: "glyphicon glyphicon-exclamation-sign",
                                cbBtnOK: function () {
                                }
                            });
                        }

                    },
                    error: function (XMLHttpRequest, textStatus, errorThrown) {
                        _self.ui.hideLoading();
                        showModalAlert({
                            title: ProntusL10n.get('admin_error'),
                            msg: ProntusL10n.get('prontus_list_load_error', errorThrown),
                            type: "red",
                            icon: "glyphicon glyphicon-exclamation-sign",
                            cbBtnOK: function () {
                            }
                        });
                    }
                })
            },
            parseNotifList: function (data) {
                var tpl_list = $('#tpl_list').html();
                var list = '';

                for (var x = 0; x < data.length; x++) {
                    var aux = tpl_list;

                    for (var prop in data[x]) {
                        aux = aux.replace(new RegExp( '{{'+prop+'}}', "g"), data[x][prop]);
                    }

                    list += aux;
                }

                $('#notif-list').html(list);
            }
        },
        ui: {
            showLoading: function () {
                $('#modal-loading-mensaje').html(ProntusL10n.get('prontus_wait_loading_info'));
                $('#modal-loading').modal({backdrop: 'static', keyboard: false});
            },
            hideLoading: function () {
              $('#modal-loading').modal('hide');
            }
        },
        helper: {
            execFunction: function (functionName, context) {
                var args = Array.prototype.slice.call(arguments, 2);
                var namespaces = functionName.split(".");
                var func = namespaces.pop();

                for(var i = 0; i < namespaces.length; i++) {
                    context = context[namespaces[i]];
                }

                if (typeof context[func] == 'undefined') {
                    showModalAlert({
                        title: ProntusL10n.get('global_error_title'),
                        type: 'red',
                        msg: ProntusL10n.get('global_missing_method', functionName)
                    });
                    return;
                }

                return context[func].apply(context, args);
            }
        }
    };

    $(document).ready(function () {
        PushNotif.init();
    });
})(window);
